@@ -3,16 +3,12 @@
 
 from typing import Optional
 
-from pluggy import HookimplMarker
+from napari_plugin_engine import napari_hook_implementation
 
 from . import core
 
 ###############################################################################
 
-napari_hook_implementation = HookimplMarker("napari")
-
-###############################################################################
-
 
 @napari_hook_implementation
 def napari_get_reader(path: core.PathLike) -> Optional[core.ReaderFunction]:
